@@ -1,4 +1,4 @@
-VERSION = (0, 18, 0, 'final')
+VERSION = (1, 0, 0, 'final')
 __version__ = VERSION  # alias
 
 
@@ -14,4 +14,10 @@ def get_version():
     return version
 
 
-default_app_config = 'rest_framework_gis.apps.AppConfig'
+try:
+    import django
+
+    if django.VERSION < (3, 2):
+        default_app_config = 'rest_framework_gis.apps.AppConfig'
+except ImportError:
+    pass
